==> dde-launchpad_0.0.2.tar.xz: BUILD/translations/dde-launchpad_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="27"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="37"/>
        <source>Pin to Top</source>
        <translation>Anclar arriba</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="43"/>
        <source>Remove from favorites</source>
        <translation>Eliminar de Favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="43"/>
        <source>Add to favorites</source>
        <translation>Añadir a Favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="57"/>
        <source>Send to desktop</source>
        <translation>Enviar al escritorio</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="57"/>
        <source>Remove from desktop</source>
        <translation>Quitar del escritorio</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="67"/>
        <source>Send to dock</source>
        <translation>Anclar al muelle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="67"/>
        <source>Remove from dock</source>
        <translation>Desanclar del muelle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="78"/>
        <source>Add to startup</source>
        <translation>Añadir al arranque</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="78"/>
        <source>Remove from startup</source>
        <translation>Quitar del arranque</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="83"/>
        <source>Use a proxy</source>
        <translation>Usar un proxy</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="86"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <location filename="../qml/AppListView.qml" line="34"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="36"/>
        <source>Chat</source>
        <translation>Mensajería</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="38"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="40"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="42"/>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="44"/>
        <source>Game</source>
        <translation>Juegos</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="46"/>
        <source>Office</source>
        <translation>Ofimática</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="48"/>
        <source>Reading</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="50"/>
        <source>Development</source>
        <translation>Desarrollo</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="52"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../qml/AppListView.qml" line="54"/>
        <source>Others</source>
        <translation>Otros</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="vanished">Buscar</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Mostrar el lanzador (oculto por defecto)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Alternar la visibilidad del lanzador</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="202"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>¿Estás seguro de que quieres desinstalar %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="210"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="218"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="41"/>
        <source>Categories</source>
        <translation>Categorías</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="117"/>
        <source>Power</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="130"/>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="73"/>
        <location filename="../qml/WindowedFrame.qml" line="154"/>
        <source>Search</source>
        <translation>Buscar en Internet</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="172"/>
        <source>My Favorites</source>
        <translation>Mis favoritos</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="203"/>
        <source>Add your favorite apps here</source>
        <translation>Añadir tus aplicaciones favoritas aquí</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="213"/>
        <source>All Apps</source>
        <translation>Todas las Aplicaciones</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="186"/>
        <location filename="../qml/WindowedFrame.qml" line="237"/>
        <source>No search results</source>
        <translation>Sin resultados de búsqueda</translation>
    </message>
</context>
</TS>

==> dde-launchpad_0.4.4.tar.xz: BUILD/translations/dde-launchpad_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="27"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="37"/>
        <source>Pin to Top</source>
        <translation>Anclar arriba</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Remove from favorites</source>
        <translation>Eliminar de Favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Add to favorites</source>
        <translation>Añadir a Favoritos</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="60"/>
        <source>Send to desktop</source>
        <translation>Enviar al escritorio</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="60"/>
        <source>Remove from desktop</source>
        <translation>Quitar del escritorio</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="70"/>
        <source>Send to dock</source>
        <translation>Anclar al muelle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="70"/>
        <source>Remove from dock</source>
        <translation>Desanclar del muelle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="81"/>
        <source>Add to startup</source>
        <translation>Añadir al arranque</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="81"/>
        <source>Remove from startup</source>
        <translation>Quitar del arranque</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="86"/>
        <source>Use a proxy</source>
        <translation>Usar un proxy</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="89"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Mensajería</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Música</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Vídeo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Gráficos</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">Juegos</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Ofimática</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Lectura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Desarrollo</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">Sistema</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">Otros</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="vanished">Buscar</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Mostrar el lanzador (oculto por defecto)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Alternar la visibilidad del lanzador</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="18"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="20"/>
        <source>Chat</source>
        <translation>Mensajería</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Game</source>
        <translation>Juegos</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Office</source>
        <translation>Ofimática</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Reading</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Development</source>
        <translation>Desarrollo</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Others</source>
        <translation>Otros</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="250"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>¿Estás seguro de que quieres desinstalar %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="258"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="266"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Categories</source>
        <translation type="vanished">Categorías</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="105"/>
        <source>Power</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Ajustes</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="338"/>
        <location filename="../qml/WindowedFrame.qml" line="260"/>
        <source>Search</source>
        <translation>Buscar en Internet</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="117"/>
        <source>Control Center</source>
        <translation>Centro de mando</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="159"/>
        <source>My Favorites</source>
        <translation>Mis favoritos</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="189"/>
        <source>Add your favorite apps here</source>
        <translation>Añadir tus aplicaciones favoritas aquí</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="200"/>
        <source>All Apps</source>
        <translation>Todas las Aplicaciones</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="323"/>
        <location filename="../qml/WindowedFrame.qml" line="224"/>
        <source>No search results</source>
        <translation>Sin resultados de búsqueda</translation>
    </message>
</context>
</TS>
